@@ -542,6 +542,21 @@ class PageBlock(BasicBlock):
 
     locked = field_map("format.block_locked")
 
+    def get_backlinks(self):
+        """
+        Returns a list of blocks that referencing the current PageBlock. Note that only PageBlocks support backlinks.
+        """
+        data = self._client.post("getBacklinksForBlock", {"blockId": self.id}).json()
+        backlinks = []
+        for block in data.get("backlinks") or []:
+            mention = block.get("mentioned_from")
+            if not mention:
+                continue
+            block_id = mention.get("block_id") or mention.get("parent_block_id")
+            if block_id:
+                backlinks.append(self._client.get_block(block_id))
+        return backlinks
+
 
 class BulletedListBlock(BasicBlock):
 
